@@ -69,7 +69,8 @@ def uv_in_uvfits(paper_miriad, tmp_path):
 
 @pytest.mark.filterwarnings("ignore:Telescope ATCA is not")
 @pytest.mark.filterwarnings("ignore:The uvw_array does not match the expected values")
-def test_read_write_read_atca(tmp_path):
+@pytest.mark.parametrize("future_shapes", [True, False])
+def test_read_write_read_atca(tmp_path, future_shapes):
     uv_in = UVData()
     uv_out = UVData()
     atca_file = os.path.join(DATA_PATH, "atca_miriad")
@@ -91,8 +92,16 @@ def test_read_write_read_atca(tmp_path):
         ],
     ):
         uv_in.read(atca_file)
+
+    if future_shapes:
+        uv_in.use_future_array_shapes()
+
     uv_in.write_miriad(testfile, clobber=True)
     uv_out.read(testfile)
+
+    if future_shapes:
+        uv_out.use_future_array_shapes()
+
     assert uv_in == uv_out
 
 
@@ -725,7 +734,7 @@ def test_miriad_extra_keywords_errors(
     (
         [["bool", "bool2"], [True, False]],
         [["int1", "int2"], [np.int64(5), 7]],
-        [["float1", "float2"], [np.int64(5.3), 6.9]],
+        [["float1", "float2"], [np.float64(5.3), 6.9]],
         [["str", "longstr"], ["hello", "this is a very long string " * 1000]],
     ),
 )
@@ -848,6 +857,24 @@ def test_miriad_antenna_diameters(uv_in_paper):
     uv_out.read(write_file)
     assert uv_in == uv_out
 
+    # check warning when antenna diameters vary
+    uv_in.antenna_diameters = (
+        np.zeros((uv_in.Nants_telescope,), dtype=np.float32) + 14.0
+    )
+    uv_in.antenna_diameters[1] = 15.0
+    with uvtest.check_warnings(
+        UserWarning,
+        match=[
+            "The uvw_array does not match the expected values",
+            "Antenna diameters are not uniform",
+        ],
+    ):
+        uv_in.write_miriad(write_file, clobber=True)
+    uv_out.read(write_file)
+    assert uv_out.antenna_diameters is None
+    uv_out.antenna_diameters = uv_in.antenna_diameters
+    assert uv_in == uv_out
+
 
 @pytest.mark.filterwarnings("ignore:The uvw_array does not match the expected values")
 def test_miriad_write_miriad_unkonwn_phase_error(uv_in_paper):
@@ -1038,9 +1065,9 @@ def test_read_write_read_miriad_partial_ant_str(uv_in_paper, tmp_path):
     "err_type,select_kwargs,err_msg",
     [
         (
-            AssertionError,
+            ValueError,
             {"ant_str": "auto", "antenna_nums": [0, 1]},
-            "ant_str must be None if antenna_nums or bls is not None",
+            "Cannot provide ant_str with antenna_nums or bls",
         ),
         (ValueError, {"bls": "foo"}, "bls must be a list of tuples of antenna numbers"),
         (
@@ -1074,32 +1101,47 @@ def test_read_write_read_miriad_partial_ant_str(uv_in_paper, tmp_path):
             "Cannot provide length-3 tuples and also specify polarizations.",
         ),
         (
-            AssertionError,
+            ValueError,
             {"antenna_nums": np.array([(0, 10)])},
-            "antenna_nums must be fed as a list of antenna number integers",
+            "antenna_nums must be a list of antenna number integers",
         ),
         (
-            AssertionError,
+            ValueError,
+            {"antenna_nums": 5},
+            "antenna_nums must be a list of antenna number integers",
+        ),
+        (
+            ValueError,
+            {"antenna_nums": ["foo"]},
+            "antenna_nums must be a list of antenna number integers",
+        ),
+        (
+            ValueError,
             {"polarizations": "xx"},
             "pols must be a list of polarization strings or ints",
         ),
+        (
+            ValueError,
+            {"polarizations": [5.3]},
+            "pols must be a list of polarization strings or ints",
+        ),
         (
             ValueError,
             {"polarizations": ["yy"]},
             "No data is present, probably as a result of select on read",
         ),
         (
-            AssertionError,
+            ValueError,
             {"time_range": "foo"},
             "time_range must be a len-2 list of Julian Date floats",
         ),
         (
-            AssertionError,
+            ValueError,
             {"time_range": [1, 2, 3]},
             "time_range must be a len-2 list of Julian Date floats",
         ),
         (
-            AssertionError,
+            ValueError,
             {"time_range": ["foo", "bar"]},
             "time_range must be a len-2 list of Julian Date floats",
         ),
@@ -1108,7 +1150,7 @@ def test_read_write_read_miriad_partial_ant_str(uv_in_paper, tmp_path):
             {"time_range": [10.1, 10.2]},
             "No data is present, probably as a result of select on read",
         ),
-        (AssertionError, {"ant_str": 0}, "ant_str must be fed as a string"),
+        (ValueError, {"ant_str": 0}, "ant_str must be a string"),
     ],
 )
 def test_read_write_read_miriad_partial_errors(
@@ -1120,24 +1162,8 @@ def test_read_write_read_miriad_partial_errors(
     full.write_miriad(write_file, clobber=True)
     uv_in = UVData()
 
-    with pytest.raises(err_type) as cm:
+    with pytest.raises(err_type, match=err_msg):
         uv_in.read(write_file, **select_kwargs)
-    assert str(cm.value).startswith(err_msg)
-
-
-@pytest.mark.filterwarnings("ignore:The uvw_array does not match the expected values")
-def test_read_write_read_miriad_partial_error_special_cases(uv_in_paper, tmp_path):
-    full, uv_out, write_file = uv_in_paper
-
-    # check partial read selections
-    full.write_miriad(write_file, clobber=True)
-    uv_in = UVData()
-
-    with pytest.raises(ValueError) as cm:
-        uv_in.read(write_file, polarizations=[1.0])
-    assert str(cm.value).startswith(
-        "Polarization 1.0 cannot be converted to a polarization number"
-    )
 
 
 @pytest.mark.filterwarnings("ignore:The uvw_array does not match the expected values")
